Index: include/core/SkMaskFilter.h |
diff --git a/include/core/SkMaskFilter.h b/include/core/SkMaskFilter.h |
index 51ede4b0ab286cdcdc12c8f32cabb8e7cbf14099..026ef40cb1e8f93d8733be6703e9af9ad04a1746 100644 |
--- a/include/core/SkMaskFilter.h |
+++ b/include/core/SkMaskFilter.h |
@@ -63,24 +63,22 @@ public: |
#if SK_SUPPORT_GPU |
/** |
* Returns true if the filter can be expressed a single-pass GrEffect without requiring an |
* explicit input mask. Per-pixel, the effect receives the incoming mask's coverage as |
* the input color and outputs the filtered covereage value. This means that each pixel's |
* filtered coverage must only depend on the unfiltered mask value for that pixel and not on |
* surrounding values. |
* |
* If effect is non-NULL, a new GrEffect instance is stored in it. The caller assumes ownership |
* of the effect and must unref it. |
*/ |
- virtual bool asNewEffect(GrEffect** effect, |
- GrTexture*, |
- const SkMatrix& ctm) const; |
+ virtual bool asFragmentProcessor(GrFragmentProcessor**, GrTexture*, const SkMatrix& ctm) const; |
/** |
* If asNewEffect() fails the filter may be implemented on the GPU by a subclass overriding |
* filterMaskGPU (declared below). That code path requires constructing a src mask as input. |
* Since that is a potentially expensive operation, the subclass must also override this |
* function to indicate whether filterTextureMaskGPU would succeeed if the mask were to be |
* created. |
* |
* 'maskRect' returns the device space portion of the mask that the filter needs. The mask |
@@ -63,24 +63,22 @@ public: |
#if SK_SUPPORT_GPU |
/** |
- * Returns true if the filter can be expressed a single-pass GrEffect without requiring an |
+ * Returns true if the filter can be expressed a single-pass GrProcessor without requiring an |
* explicit input mask. Per-pixel, the effect receives the incoming mask's coverage as |
* the input color and outputs the filtered covereage value. This means that each pixel's |
@@ -63,24 +63,22 @@ public: |
* surrounding values. |
* |
- * If effect is non-NULL, a new GrEffect instance is stored in it. The caller assumes ownership |
- * of the effect and must unref it. |
+ * If effect is non-NULL, a new GrProcessor instance is stored in it. The caller assumes |
+ * ownership of the effect and must unref it. |
*/ |
@@ -63,24 +63,22 @@ public: |
/** |
- * If asNewEffect() fails the filter may be implemented on the GPU by a subclass overriding |
- * filterMaskGPU (declared below). That code path requires constructing a src mask as input. |
- * Since that is a potentially expensive operation, the subclass must also override this |
- * function to indicate whether filterTextureMaskGPU would succeeed if the mask were to be |
+ * If asFragmentProcessor() fails the filter may be implemented on the GPU by a subclass |
+ * overriding filterMaskGPU (declared below). That code path requires constructing a src mask |
+ * as input. Since that is a potentially expensive operation, the subclass must also override |
+ * this function to indicate whether filterTextureMaskGPU would succeeed if the mask were to be |
* created. |
* |